ez_log: Simple logging library for Rust
Features
Ez_log can be configured using Rust features.
Default features:
color: Colored terminal output.time: Adds time for every log output. Time format can be configured by editingEZ_LOG_TIME_FORMATenv variable, using chrono format syntax.
Optional features:
dump: Creates file for every day and writes to it log output. Directory for those files can be configured by editingEZ_LOG_LOGS_DIRenv variable.
Macros
- log_
error log_error!macro is used to log errors.- log_
info log_info!macro is used to log informations.- log_
warn log_warn!macro is used to log warning.